import glob, os, shutil, os, sys
sys.path.append("synesthesia")

from synesthesia.gui import *
from synesthesia.essentia_helper import *
from synesthesia.lib import *
from synesthesia.wsl import *
from synesthesia import *